@@ -15,9 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Symbols"""
-from pydsl.Check import check
-
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2014, Nestor Arocha"
 __email__ = "nesaro@gmail.com"
@@ -25,55 +22,39 @@ __email__ = "nesaro@gmail.com"
 import logging
 LOG = logging.getLogger(__name__)
 from pydsl.Grammar.Definition import Grammar, String
+from pydsl.Check import check
 
 class Symbol(object):
-    def __init__(self, weight):
-        self._weight = weight
+    pass
 
-    @property
-    def weight(self):
-        return self._weight
-
-class NonTerminalSymbol(Symbol):
-    def __init__(self, name,  weight = 50):
-        Symbol.__init__(self, weight)
-        self.name = name
+class NonTerminalSymbol(str, Symbol):
+    def __init__(self, name):
+        Symbol.__init__(self)
 
     def __str__(self):
-        return "<NonTS: " + self.name + ">"
+        return "<NonTS: " + self + ">"
 
     def __hash__(self):
-        return hash(self.name) ^ hash(self.weight)
+        return str.__hash__(self)
 
     def __eq__(self, other):
         if not isinstance(other, NonTerminalSymbol):
             return False
-        return self.name == other.name and self.weight == other.weight
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
+        return str.__eq__(self,other)
 
 
 class TerminalSymbol(Symbol):
 
-    def __init__(self, gd, weight=None, boundariesrules=None):
+    def __init__(self, gd):
         if not isinstance(gd, Grammar):
-            raise TypeError
-        if isinstance(gd, String):
-            weight = weight or 99
-            boundariesrules = len(gd)
-        else:
-            weight = weight or 49
-        Symbol.__init__(self, weight)
-        if boundariesrules not in ("min", "max", "any") and not isinstance(boundariesrules, int):
-            raise TypeError("Unknown boundaries rules %s" % boundariesrules)
+            raise TypeError("Expected Grammar, got %s" % (gd,))
+        Symbol.__init__(self)
         if not gd:
             raise Exception
         self.gd = gd
-        self.boundariesrules = boundariesrules
 
     def __hash__(self):
-        return hash(self.gd) ^ hash(self.boundariesrules)
+        return hash(self.gd)
 
     def check(self, data):# ->bool:
         """Checks if input is recognized as this symbol"""
@@ -85,7 +66,7 @@ class TerminalSymbol(Symbol):
     def __eq__(self, other):
         """StringTerminalSymbol are equals if definition and names are equal"""
         try:
-            return self.gd == other.gd and self.boundariesrules == other.boundariesrules
+            return self.gd == other.gd
         except AttributeError:
             return False
 
@@ -93,8 +74,11 @@ class TerminalSymbol(Symbol):
         return "<TS: " + str(self.gd) + ">"
 
 class NullSymbol(Symbol):
-    def __init__(self):
-        Symbol.__init__(self, 100)
+    _instance = None
+    def __new__(cls):
+        if not cls._instance:
+            cls._instance = super(NullSymbol, cls).__new__(cls)
+        return cls._instance
 
     def __eq__(self, other):
         return isinstance(other, NullSymbol)
@@ -106,17 +90,19 @@ class NullSymbol(Symbol):
         return False
 
 class EndSymbol(Symbol):
-    def __init__(self):
-        Symbol.__init__(self, 100)
+    _instance = None
+    def __new__(cls):
+        if cls._instance is None:
+            cls._instance = super(EndSymbol, cls).__new__(cls)
+        return cls._instance
 
     def __hash__(self):
-        return hash(str(self))
+        assert(EndSymbol._instance is not None)
+        return hash(id(self._instance))
 
     def __eq__(self, other):
-        return isinstance(other, EndSymbol)
-
-    def __ne__(self, other):
-        return not self.__eq__(other)
+        result = isinstance(other, EndSymbol) or EndSymbol == other
+        return result
 
     def __bool__(self):
         return False
