@@ -15,7 +15,7 @@
 #You should have received a copy of the GNU General Public License
 #along with pydsl.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Python Transformers"""
+"""Python Translators"""
 
 __author__ = "Nestor Arocha"
 __copyright__ = "Copyright 2008-2014, Nestor Arocha"
@@ -32,11 +32,7 @@ class PythonTranslator(object):
         self.outputchanneldic = outputdic
 
     def __call__(self, *args, **kwargs):
-        for dickey in kwargs.keys():
-            if not self.inputchanneldic[dickey].check(kwargs[dickey]):
-                raise ValueError("Invalid value %s for input %s (%s)" % (kwargs[dickey], dickey, self))
-        result = self._function(*args, **kwargs)
-        return result
+        return self._function(*args, **kwargs)
 
 class PLYTranslator(object):
     def __init__(self, grammardefinition):
@@ -57,19 +53,13 @@ class PyParsingTranslator(object):
 
 class ParsleyTranslator(object):
     def __init__(self, grammar):
-        self.g=grammar
+        self.gd=grammar
+
     def __call__(self, input):
-        return self.g.match(input)
+        return getattr(self.gd.grammar(input), self.gd.root_rule)() #call grammar(data).root_rule()
 
 
 def translator_factory(function):
-    def _load_checker(originaldic):
-        """Converts {"channelname","type"} into {"channelname",instance}"""
-        result = {}
-        for key in originaldic:
-            from pydsl.Check import checker_factory
-            result[key] = checker_factory(load(str(originaldic[key]))) #FIXME: load is no longer available
-        return result
     from pydsl.Grammar.Definition import PLYGrammar
     from pydsl.Grammar.Parsley import ParsleyGrammar
     if isinstance(function, PLYGrammar):
@@ -77,8 +67,6 @@ def translator_factory(function):
     if isinstance(function, ParsleyGrammar):
         return ParsleyTranslator(function)
     if isinstance(function, dict):
-        function['inputdic'] = _load_checker(function['inputdic'])
-        function['outputdic'] = _load_checker(function['outputdic'])
         return PythonTranslator(**function)
     from pyparsing import OneOrMore
     if isinstance(function, OneOrMore):
